import 'dart:async';
import 'package:flutter/material.dart';
import 'package:better_player/better_player.dart';

class BetterPlayerFullscreenIssue extends StatefulWidget {
  createState() => _BetterPlayerFullscreenIssueState();
}

class _BetterPlayerFullscreenIssueState extends State<BetterPlayerFullscreenIssue> {
  final List<String> sources = [
    'https://firebasestorage.googleapis.com/v0/b/tivio-dev.appspot.com/o/assets%2Fstatic%2Fad1.mp4?alt=media',
    'https://firebasestorage.googleapis.com/v0/b/tivio-dev.appspot.com/o/assets%2Fstatic%2Fad2.mp4?alt=media',
    'https://firebasestorage.googleapis.com/v0/b/tivio-dev.appspot.com/o/assets%2Fstatic%2Fad3.mp4?alt=media',
    'https://firebasestorage.googleapis.com/v0/b/tivio-dev.appspot.com/o/assets%2Fstatic%2Fad4.mp4?alt=media',
    'https://firebasestorage.googleapis.com/v0/b/tivio-dev.appspot.com/o/assets%2Fstatic%2Fad5.mp4?alt=media',
  ];
  int lastSourceIndex = 0;
  BetterPlayerController betterPlayerController;
  Timer timer;

  @override
  void initState() {
    super.initState();
    startChangingSources();
  }

  startChangingSources() {
    changeSource();
    timer = Timer.periodic(Duration(seconds: 5), (timer) => changeSource());
  }

  changeSource() {
    if (betterPlayerController != null) {
      betterPlayerController.pause();
    }

    var config = BetterPlayerConfiguration(
      aspectRatio: 16 / 9,
      autoPlay: true,
      fullScreenByDefault: true,
      controlsConfiguration: BetterPlayerControlsConfiguration(
        playerTheme: BetterPlayerTheme.material,
      ),
    );

    var source = BetterPlayerDataSource(
      BetterPlayerDataSourceType.network,
      sources[lastSourceIndex],
    );

    setState(() {
      betterPlayerController = BetterPlayerController(config);
      betterPlayerController.setupDataSource(source);

      lastSourceIndex = (lastSourceIndex >= sources.length - 1) ? 0 : lastSourceIndex + 1;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Container(
        child: (betterPlayerController != null)
            ? BetterPlayer(
                controller: betterPlayerController,
              )
            : null,
      ),
    );
  }

  @override
  void dispose() {
    timer.cancel();
    betterPlayerController = null;
    super.dispose();
  }
}
