import 'package:flutter/material.dart';
import 'package:tivio_sdk/tivio.dart';

class StreamTestPage extends StatelessWidget {
  final Tivio _tivio;

  StreamTestPage(this._tivio);

  printAllData() async {
    /// Widget

    print('subscribeToWidget');
    var widgetStream = _tivio.subscribeToWidget(widgetId: 'FlutterDemo');

    widgetStream.stream.listen((event) {
      print('widget id: ${event.id} name: ${event.name}');
    });

    await Future.delayed(Duration(seconds: 1));
    widgetStream.close();
    print('close subscribeToWidget\n');

    /// Channels

    print('subscribeToChannelsInWidget');
    var channelsStream = _tivio.subscribeToChannelsInWidget(widgetId: 'FlutterDemo');
    channelsStream.stream.listen((event) {
      print('length: ${event.records.length}, hasNextPage: ${event.hasNextPage}');
      event.records.forEach((element) {
        print('channel id: ${element.id}, name: ${element.name}');
      });
    });

    await Future.delayed(Duration(seconds: 1));
    channelsStream.close();
    print('close subscribeToChannelsInWidget\n');

    print('subscribeToChannel');
    var channelStream = _tivio.subscribeToChannel(channelId: 'Xz9YFNQ5dLQj6I8sAXEf');
    channelStream.stream.listen((event) {
      print('channel id: ${event.id}, name: ${event.name}');
    });

    await Future.delayed(Duration(seconds: 1));
    channelStream.close();
    print('close subscribeToChannel\n');

    /// Sections

    print('subscribeToSectionsInChannel');
    var sectionsStream = _tivio.subscribeToSectionsInChannel(channelId: 'LzqDUHWGqEPUn6LcEjYN');
    sectionsStream.stream.listen((event) {
      print('length: ${event.records.length}, hasNextPage: ${event.hasNextPage}');
      event.records.forEach((element) {
        print('section id: ${element.id}, name: ${element.name}');
      });
    });

    await Future.delayed(Duration(seconds: 1));
    sectionsStream.close();
    print('close subscribeToSectionsInChannel\n');

    print('subscribeToSection');
    var sectionStream = _tivio.subscribeToSection(sectionId: 'Lhkb2QD0Sqg40InUPzfy');
    sectionStream.stream.listen((event) {
      print('section id: ${event.id}, name: ${event.name}');
    });

    await Future.delayed(Duration(seconds: 1));
    sectionStream.close();
    print('close subscribeToSection\n');

    /// Videos

    print('subscribeToVideosInSection');
    var videosStream = _tivio.subscribeToVideosInSection(sectionId: 'uSBCtAYAepM55HUmLGSj');
    videosStream.stream.listen((event) {
      print('length: ${event.records.length}, hasNextPage: ${event.hasNextPage}');
      event.records.forEach((element) {
        print('video id: ${element.id}, name: ${element.name}, url: ${element.url.hls}');
      });
    });

    await Future.delayed(Duration(seconds: 1));
    videosStream.close();
    print('close subscribeToVideosInSection\n');

    print('subscribeToVideo');
    var videoStream = _tivio.subscribeToVideo(videoId: 'FDQOZB4usp041blIXJ0N');
    videoStream.stream.listen((event) {
      print('video id: ${event.id}, name: ${event.name}, url: ${event.url.hls}');
    });

    await Future.delayed(Duration(seconds: 1));
    print('close subscribeToVideo\n');
    videoStream.close();
  }

  printChannelsInWidgetPerPage() async {
    print('subscribeToChannelsInWidget');
    var channelsStream = _tivio.subscribeToChannelsInWidget(widgetId: 'FlutterDemo', count: 1);
    channelsStream.stream.listen((event) {
      print('length: ${event.records.length}, hasNextPage: ${event.hasNextPage}');
      event.records.forEach((element) {
        print('channel id: ${element.id}, name: ${element.name}');
      });
    }, onError: (event) {
      print('subscribeToChannelsInWidget onError');
      print(event);
    });

    var i = 1;
    while (i <= 5) {
      await Future.delayed(Duration(milliseconds: 2500));

      print('subscribeToChannelsInWidget $i');
      _tivio.fetchNextChannelsInWidget(widgetId: 'FlutterDemo', count: 1);

      i++;
    }

    await Future.delayed(Duration(seconds: 1));
    channelsStream.close();
    print('close subscribeToChannelsInWidget');
  }

  printSectionsInChannelPerPage() async {
    print('subscribeToSectionsInChannel');
    var sectionsStream = _tivio.subscribeToSectionsInChannel(channelId: 'LzqDUHWGqEPUn6LcEjYN', count: 1);
    sectionsStream.stream.listen((event) {
      print('length: ${event.records.length}, hasNextPage: ${event.hasNextPage}');
      event.records.forEach((element) {
        print('section id: ${element.id}, name: ${element.name}');
      });
    }, onError: (event) {
      print('subscribeToChannelsInWidget onError');
      print(event);
    });

    var i = 1;
    while (i <= 5) {
      await Future.delayed(Duration(milliseconds: 2500));

      print('subscribeToChannelsInWidget $i');
      _tivio.fetchNextSectionsInChannel(channelId: 'LzqDUHWGqEPUn6LcEjYN', count: 1);

      i++;
    }

    await Future.delayed(Duration(seconds: 1));
    sectionsStream.close();
    print('close subscribeToSectionsInChannel');
  }

  printVideosInSectionPerPage() async {
    print('subscribeToVideosInSection');
    var videosStream = _tivio.subscribeToVideosInSection(sectionId: 'Lhkb2QD0Sqg40InUPzfy', count: 1);
    videosStream.stream.listen((event) {
      print('new event');
      print('length: ${event.records.length}, hasNextPage: ${event.hasNextPage}');
      event.records.forEach((element) {
        print('video id: ${element.id}, name: ${element.name}, url: ${element.url.hls}');
      });
    });

    var i = 1;
    while (i <= 6) {
      await Future.delayed(Duration(milliseconds: 2500));

      print('fetchNextVideosInSection $i');
      _tivio.fetchNextVideosInSection(sectionId: 'Lhkb2QD0Sqg40InUPzfy', count: 1);

      i++;
    }

    await Future.delayed(Duration(seconds: 1));
    print('close subscribeToVideosInSection');
    videosStream.close();
  }

  printRecentVideos() async {
    print('subscribeRecentVideosInWidget');
    var widgetRecentStream = _tivio.subscribeToRecentVideosInWidget(widgetId: 'FlutterDemo');
    widgetRecentStream.stream.listen((event) {
      print('widget recent length: ${event.records.length}');
      event.records.forEach((element) {
        print('widget recent: ${element.name}');
      });
    });

    print('subscribeRecentVideosInChannel');
    var channelRecentStream = _tivio.subscribeToRecentVideosInChannel(channelId: 'LzqDUHWGqEPUn6LcEjYN');
    channelRecentStream.stream.listen((event) {
      print('channel recent length: ${event.records.length}');
      event.records.forEach((element) {
        print('channel recent: ${element.name}');
      });
    });

    await Future.delayed(Duration(seconds: 2));
    print('close subscribeRecentVideosInWidget');
    print('close subscribeRecentVideosInChannel');

    widgetRecentStream.close();
    channelRecentStream.close();
  }

  runAll() async {
    await printAllData();

    await printChannelsInWidgetPerPage();
    await printSectionsInChannelPerPage();
    await printVideosInSectionPerPage();

    await printRecentVideos();
  }

  @override
  Widget build(BuildContext context) {
    runAll();

    return Scaffold(
      appBar: AppBar(
        title: Text('Stream test page'),
      ),
    );
  }
}
