import 'package:flutter/material.dart';
import 'package:tivio_sdk/tivio.dart';
import './tivio_videos_widget.dart';

class TivioSectionsWidget extends StatefulWidget {
  final Tivio _tivio;
  final String _channelId;

  TivioSectionsWidget(this._tivio, this._channelId, {Key key}) : super(key: key);

  createState() => _TivioSectionsState();
}

class _TivioSectionsState extends State<TivioSectionsWidget> {
  List<TivioDataSection> _sections = [];
  TivioDataStream<TivioDataPagination<TivioDataSection>> _sectionsStream;

  @override
  void initState() {
    super.initState();
    subscribeToVideos();
  }

  subscribeToVideos() {
    _sectionsStream = widget._tivio.subscribeToSectionsInChannel(channelId: widget._channelId);
    _sectionsStream.stream.listen((event) {
      setState(() {
        _sections = event.records;
      });
    });
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      children: [
        ..._sections
            .map((section) => Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: [
                    Text(section.name,
                        style: TextStyle(
                          fontSize: 18,
                          fontWeight: FontWeight.bold,
                        )),
                    TivioVideosWidget(widget._tivio, section.id, widget._channelId),
                  ],
                ))
            .toList(),
      ],
    );
  }

  @override
  void dispose() {
    _sectionsStream.close();
    super.dispose();
  }
}
