import 'package:flutter/material.dart';
import 'package:tivio_sdk/tivio.dart';
import 'package:nav_router/nav_router.dart';
import 'tivio_player_fullscreen.dart';

class TivioVideosWidget extends StatefulWidget {
  final Tivio _tivio;
  final String _sectionId;
  final String _channelId;

  TivioVideosWidget(this._tivio, this._sectionId, this._channelId);

  @override
  createState() => _TivioVideosWidgetState();
}

class _TivioVideosWidgetState extends State<TivioVideosWidget> {
  List<TivioDataVideo> _videos = [];
  TivioDataStream<TivioDataPagination<TivioDataVideo>> _videosStream;

  @override
  void initState() {
    super.initState();
    subscribeToVideos();
  }

  subscribeToVideos() {
    _videosStream = widget._tivio.subscribeToVideosInSection(sectionId: widget._sectionId);
    _videosStream.stream.listen((event) {
      setState(() {
        _videos = event.records;
      });
    });
  }

  @override
  Widget build(BuildContext context) {
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: [
        ..._videos
            .map((video) => MaterialButton(
                  onPressed: (!video.isPlaylist)
                      ? () => _navigateToPage(TivioPlayerFullscreen(
                            tivio: widget._tivio,
                            source: video,
                          ))
                      : null,
                  child: Text(video.name),
                ))
            .toList(),
      ],
    );
  }

  @override
  void dispose() {
    _videosStream.close();
    super.dispose();
  }

  _navigateToPage(Widget page) {
    return routePush(page, RouterType.material);
  }
}
