import '../dto.dart';

class TivioDataVideoParser {
  static TivioDataVideo parseVideo(Map data) {
    if (data['name'] == null) {
      return null;
    }

    List<TivioDataPlaylistItem> playlist = [];

    for (var playlistItem in data['chapters']) {
      playlist.add(TivioDataPlaylistItem(
        playlistItem['name'],
        playlistItem['uri'],
        Duration(milliseconds: playlistItem['duration'] ?? 0),
      ));
    }

    return TivioDataVideo(
      data['id'],
      data['name'],
      Duration(milliseconds: data['duration'] ?? 0),
      (data['created'] != null) ? DateTime.parse(data['created']) : null,
      data['url'] ?? '',
      data['cover'] ?? '',
      data['isPlaylist'] ?? false,
      playlist,
      data['monetization'],
    );
  }

  static TivioDataPagination<TivioDataVideo> parsePaginatedVideos(Map data) {
    var records = data['records'] ?? [];
    var videos = records
        .map<TivioDataVideo>(
          (video) => TivioDataVideoParser.parseVideo(
            video,
          ),
        )
        .where((element) => element != null)
        .toList();

    return TivioDataPagination(videos, data['hasNextPage'] ?? false);
  }
}
