import '../utils/enum.dart';

enum TivioPlayerWrapperInputSourceType {
  Vod,
  Channel,
  Advertisement,
}

abstract class TivioPlayerInputSource {
  String id;
  String uri;
  Duration skipDelay;
  Duration duration;
  TivioPlayerWrapperInputSourceType type;

  toObject();
}

class TivioPlayerAdSource extends TivioPlayerInputSource {
  final String uri;
  final String id;
  final String name;
  final String description;
  final Duration skipDelay;
  final Duration duration;
  final bool isSkippable;
  final TivioPlayerWrapperInputSourceType type = TivioPlayerWrapperInputSourceType.Advertisement;

  TivioPlayerAdSource({
    this.uri,
    this.id,
    this.name,
    this.description,
    this.duration,
    this.skipDelay,
    this.isSkippable,
  });

  toObject() {
    return {
      'uri': this.uri,
      'id': this.id,
      'name': this.name,
      'description': this.description,
      'duration': this.duration.inMilliseconds,
      'skipDelay': this.skipDelay.inMilliseconds,
      'isSkippable': this.isSkippable,
      'type': enumToString(this.type),
    };
  }

  static TivioPlayerAdSource fromDynamic(Map data) {
    return TivioPlayerAdSource(
      uri: data['uri'],
      id: data['id'],
      name: data['name'],
      description: data['description'],
      duration: (data['durationMs'] != null) ? Duration(milliseconds: data['durationMs']) : null,
      skipDelay: (data['skipDelayMs'] != null) ? Duration(milliseconds: data['skipDelayMs']) : null,
      isSkippable: data['isSkippable'],
    );
  }
}

class TivioPlayerVodSource extends TivioPlayerInputSource {
  final String uri;
  final String id;
  final String name;
  final String description;
  final TivioPlayerWrapperInputSourceType type = TivioPlayerWrapperInputSourceType.Vod;

  TivioPlayerVodSource({
    this.uri,
    this.id,
    this.name,
    this.description,
  });

  toObject() {
    return {
      'uri': this.uri,
      'id': this.id,
      'name': this.name,
      'description': this.description,
      'type': enumToString(this.type),
    };
  }

  static TivioPlayerVodSource fromDynamic(Map data) {
    return TivioPlayerVodSource(
      uri: data['uri'],
      id: data['videoId'],
      name: data['name'],
      description: data['description'],
    );
  }
}
