import 'dart:async';

/// @see https://dart.academy/streams-and-sinks-in-dart-and-flutter/
/// @see https://egghead.io/lessons/flutter-capture-and-handle-data-sequences-with-streams-in-dart
/// @see https://www.burkharts.net/apps/blog/fundamentals-of-dart-streams/
class TivioDataStream<T> {
  StreamController<T> _controller;

  TivioDataStream(this._controller);

  Stream<T> get stream {
    return _controller.stream;
  }

  set controller(StreamController<T> controller) {
    _controller = controller;
  }

  close() {
    return _controller.close();
  }
}

class TivioDataStreamController<T> {
  StreamController<T> _controller;
  TivioDataStream<T> tivioDataStream;

  TivioDataStreamController() {
    _controller = StreamController<T>();
    tivioDataStream = TivioDataStream<T>(_controller);
  }

  reopenIfIsClosed() {
    if (_controller.isClosed) {
      _controller = StreamController<T>();
      tivioDataStream.controller = _controller;
    }
  }

  addSafely(T payload) {
    if (!_controller.isClosed) {
      _controller.add(payload);
    }
  }

  addErrorSafely(Error error) {
    if (!_controller.isClosed) {
      _controller.addError(error);
    }
  }

  close() {
    return _controller.close();
  }
}
